@@ -1,6 +1,3 @@
-context("Get File Extension")
-library("datasets")
-
 test_that("File extension converted correctly", {
     expect_that(get_ext("hello.csv"), equals("csv"))
     expect_that(get_ext("hello.CSV"), equals("csv"))
@@ -21,8 +18,11 @@ test_that("Format converted correctly", {
 })
 
 test_that("Export without file specified", {
-    expect_true(export(iris, format = "csv") %in% dir())
-    unlink("iris.csv")
+    withr::with_tempdir(code = {
+        project_path <- getwd()
+        export(iris, format = "csv")
+        expect_true(file.exists(file.path(project_path, "iris.csv")))
+    })
 })
 
 test_that(".check_pkg_availability", {
