@@ -1,4 +1,4 @@
-context("Remote Files")
+skip_on_cran()
 
 test_that("Import Remote Stata File", {
     f <- try(import("http://www.stata-press.com/data/r13/auto.dta"))
@@ -8,7 +8,7 @@ test_that("Import Remote Stata File", {
 })
 
 test_that("Import Remote GitHub File", {
-    rfile <- "https://raw.githubusercontent.com/leeper/rio/master/inst/examples/no_header.csv"
+    rfile <- "https://raw.githubusercontent.com/gesistsa/rio/main/tests/testdata/noheader.csv"
     rfile_imported1 <- try(import(rfile))
     if (!inherits(rfile_imported1, "try-error")) {
         expect_true(inherits(rfile_imported1, "data.frame"), label = "Import remote file (implied format)")
@@ -23,16 +23,17 @@ test_that("Import Remote GitHub File", {
         expect_true(file.exists(lfile), label = "Remote file copied successfully")
         expect_true(inherits(import(lfile), "data.frame"), label = "Import local copy successfully")
     }
+    ## short url
+    payload <- try(import("https://is.gd/NLAxtg"))
+    if (!inherits(payload, "try-error")) {
+        expect_true(inherits(payload, "data.frame"), label = "Import remote file from shorten url (implied format)")
+    }
+    ## no extension
+    noextension_url <- "https://github.com/gesistsa/rio/raw/main/tests/testdata/iris_no_extension_xls"
+    expect_error(import(noextension_url))
+    expect_error(import(noextension_url, format = "xls"), NA)
 })
 
-## test_that("Import Remote File from Shortened URL", {
-##     skip_if_not_installed(pkg = "data.table")
-##     shorturl <- try(import("https://raw.githubusercontent.com/gesistsa/rio/main/tests/testdata/example.csvy"))
-##     if (!inherits(shorturl, "try-error")) {
-##         expect_true(inherits(shorturl, "data.frame"), label = "Import remote file")
-##     }
-## })
-
 test_that("Import from Google Sheets", {
     googleurl1 <- "https://docs.google.com/spreadsheets/d/1I9mJsS5QnXF2TNNntTy-HrcdHmIF9wJ8ONYvEJTXSNo/edit#gid=0"
     expect_true(inherits(import(googleurl1), "data.frame"), label = "Import google sheets (specified sheet)")
